#!/bin/bash
#
# This script MUST be always executed having root privileges:
#	$ sudo ./postbuild.sh <spawn-install-dir> <spawn-tool> [ <srv-certs.store location> ]
#
# In order to avoid to provide the root password whenever execute the 
# sudo postbuild.sh command (used to make spawner, see makefile.spawner)
# please do the following:
#
# - create a text file (example sudoers-ext) inside the etc/sudoers.d folder.
#   basically this file extends the /etc/sudoers file which is recommended 
#   to remain unchanged.
# - open to edit this file using visudo and add the following line:
#
# username ALL=(ALL) NOPASSWD: /p2j_path/src/native/postbuild.sh
#
# - replace username with your Linux account name and change the path to
#   the location of your p2j project folder. 
#   Example for user mag:
#
# mag ALL=(ALL) NOPASSWD: /home/mag/p2j/src/native/postbuild.sh
#
# - save your changes.
# - the mode of the file sudoers-ext should be 0440.
# - please check and change if necessary (chmod 0440 sudoers-ext)
#
# - open etc/sudoers file using visudo editor and check if you already 
#   have a directive like:
#	#includedir /etc/sudoers.d
# - if not please add this line at the end of your etc/sudoers file.
#
# - if this does not work on your Linux distribution you may edit
#   directly the /etc/sudoers file. (not recommended if you already 
#   have an /etc/sudores.d folder alternative)
#

if [ $# -eq 0 ]
then
   echo "Usage: $0 <spawn-install-dir> <spawn-tool> [ <srv-certs.store location> ]"
   exit 1
fi

if [ $# -eq 2 ]
then
   echo "Installing the spawn tool from $2 into $1/spawn ..."
else
   echo "Installing the spawn tool from $2 into $1/spawn using $3 as srv-certs.store file..."
fi

if [ ! -d "$1" ]
then
   echo "$1 does not exist!"
   exit 1
fi

if [ ! -f $2 ]
then
   echo "$2 does not exist!"
   exit 1
fi

P2J_JAR="../lib/p2j.jar"
if [ ! -f $P2J_JAR ]
then
   echo "$P2J_JAR does not exist!"
   exit 1
fi

if [ $# -eq 3 ]
then
   if [ ! -f "$3" ]
   then
      echo "$3 does not exist!"
      exit 1
   fi

   cp -f $3 $1/srv-certs.store
else
   echo "WARNING! The srv-certs.store file was not specified."
fi

cp -f $2 $1/spawn
cp -f $P2J_JAR $1/p2j.jar

sudo chown root:root $1/spawn $1/p2j.jar 
sudo chmod 4755 $1/spawn
sudo chmod 0550 $1/p2j.jar

if [ -f "$1/srv-certs.store" ]
then
   sudo chown root:root $1/srv-certs.store
   sudo chmod 0550 $1/srv-certs.store
fi
